%define kbddir		/usr/lib/kbd
%define mdv_keymaps_ver	20081113

Name:   	kbd
Version:	2.5.1
Release:	%mkrel 1
Summary:	Keyboard and console utilities for Linux
License:	GPLv2+
Group:  	Terminals
URL:    	https://kbd-project.org/
Source0:	https://mirrors.edge.kernel.org/pub/linux/utils/kbd/kbd-%{version}.tar.xz
Source1:	vlock.pamd
Source2:	ucwfonts.tar.bz2
# This URL is no longer valid
Source3:	ftp://ftp.linux-france.org/pub/macintosh/kbd-mac-fr-4.1.tar.gz
Source5:	kbd-mdv-keymaps-%{mdv_keymaps_ver}.tar.bz2
Source6:	configure_keyboard.sh
Source7:	setsysfont
%define bepo_version 1.0rc2
# downloaded from http://bepo.fr/wiki/Console_GNU/Linux
Source8:        fr-dvorak-bepo-keymaps-%{bepo_version}.tgz
# mageia keyboard updates
Patch0: 	kbd-1.15-mageia.patch
# tilde with twosuperior in french keyboard
Patch1: 	kbd-1.15-tilde_twosuperior_french_kbd.patch
# some modifications to cover PPC using Linux keycodes
Patch2: 	kbd-1.12-ppc_using_linux_keycodes.patch
# thai support, I tried to convert it from console-tools package
# (support added by Pablo), see these patches as reference:
# https://linux.thai.net/~thep/th-console/console-tools/console-tools-thai_ksym.patch
# https://linux.thai.net/~thep/th-console/console-data/console-data-thai_orig-1999.08.29.patch
# (note: thai_ksym patch not needed anymore, it's merged in kbd)
Patch4: 	kbd-1.12-data_thai.patch
# avoid kbd scheme for loadkeys, we use unicode_start in configure_keyboard.sh
Patch5: 	kbd-2.5.0-unicode_start_no_loadkeys.patch
# (fc) remove unneeded calls in unicode_stop
Patch6:		kbd-2.5.0-remove-unneeded-calls.patch
# fix decimal separator in Swiss German keyboard layout, fedora (rhbz#882529)
Patch9:		kbd-1.15.5-sg-decimal-separator.patch
BuildRequires:	bison
BuildRequires:	flex
BuildRequires:	gcc
BuildRequires:	gettext-devel
BuildRequires:	glibc-devel
BuildRequires:	make
BuildRequires:	pam-devel
BuildRequires:	pkgconfig(check)
Requires(pre):	filesystem >= 2.1.9-18

Provides:	vlock = %{version}-%{release}

%description
This package contains utilities to load console fonts and keyboard maps.
It also includes a number of different fonts and keyboard maps.

%prep
%setup -q -a 2
%patch0 -p1
%patch1 -p1
%ifarch ppc ppc64
%patch2 -p1
%endif
%patch4 -p1
%patch5 -p1
%patch6 -p1
%patch9 -p1

mkdir mac_frnew; cd mac_frnew
tar -zxf %{_sourcedir}/kbd-mac-fr-4.1.tar.gz
gunzip mac-fr-ext_new.kmap.gz
mv mac-fr-ext_new.kmap ../data/keymaps/mac/all/mac-fr-ext_new.map
cd ..; rm -rf mac_frnew

tar xzf %{SOURCE8}
mv fr-dvorak-bepo-keymaps-%{bepo_version}/fr-dvorak-bepo-utf8.map \
   fr-dvorak-bepo-keymaps-%{bepo_version}/fr-dvorak-bepo.map \
   data/keymaps/i386/dvorak
gzip data/keymaps/i386/dvorak/fr-dvorak-bepo-utf8.map
gzip data/keymaps/i386/dvorak/fr-dvorak-bepo.map

pushd data
tar -jxf %{_sourcedir}/kbd-mdv-keymaps-%{mdv_keymaps_ver}.tar.bz2
cp keymaps/i386/include/delete.inc keymaps/i386/include/delete.map
popd

%build
autoreconf -fi
%configure --datadir=%{kbddir} \
               --mandir=%{_mandir} \
               --enable-nls \
               --localedir=%{_datadir}/locale \
               --disable-rpath
%make_build

%install
%make_install \
	localedir=%{_datadir}/locale

# keep some keymap/consolefonts compatibility with console-tools
ln -s fr-latin9.map.gz \
	%{buildroot}%{kbddir}/keymaps/i386/azerty/fr-latin0.map.gz
ln -s us-acentos.map.gz \
	%{buildroot}%{kbddir}/keymaps/i386/qwerty/us-intl.map.gz
ln -s mac-us.map.gz \
	%{buildroot}%{kbddir}/keymaps/mac/all/mac-br-abnt2.map.gz
ln -s mac-us.map.gz \
	%{buildroot}%{kbddir}/keymaps/mac/all/mac-gr.map.gz
ln -s mac-us.map.gz \
	%{buildroot}%{kbddir}/keymaps/mac/all/mac-cz-us-qwertz.map.gz
ln -s mac-us.map.gz \
	%{buildroot}%{kbddir}/keymaps/mac/all/mac-hu.map.gz
ln -s mac-us.map.gz \
	%{buildroot}%{kbddir}/keymaps/mac/all/mac-Pl02.map.gz
ln -s mac-us.map.gz \
	%{buildroot}%{kbddir}/keymaps/mac/all/mac-ru1.map.gz
ln -s mac-us.map.gz \
	%{buildroot}%{kbddir}/keymaps/mac/all/mac-jp106.map.gz
ln -s iso07u-16.psfu.gz \
	%{buildroot}%{kbddir}/consolefonts/iso07.f16.psfu.gz
ln -s lat5-16.psfu.gz \
	%{buildroot}%{kbddir}/consolefonts/lat5u-16.psfu.gz

# Our initscripts/drakx-kbd-mouse-x11 may want to load these directly as
# they were like this when using console-tools (GRP_TOGGLE), so we do
# this to keep compatibility (#32284)
for toggle_file in alt_shift_toggle caps_toggle ctrl_alt_toggle \
                   ctrl_shift_toggle lwin_toggle menu_toggle \
                   rwin_toggle toggle
do
	cp %{buildroot}%{kbddir}/keymaps/i386/include/$toggle_file.inc \
	   %{buildroot}%{kbddir}/keymaps/i386/include/$toggle_file.map
	gzip %{buildroot}%{kbddir}/keymaps/i386/include/$toggle_file.map
done

mkdir -p %{buildroot}/%{_sysconfdir}/profile.d
install -m 644 %{_sourcedir}/configure_keyboard.sh \
	%{buildroot}/%{_sysconfdir}/profile.d/40configure_keyboard.sh

mkdir -p %{buildroot}/%{_sysconfdir}/rc.d/init.d

mkdir %{buildroot}%{_sbindir}
install -m 0755 %{_sourcedir}/setsysfont %{buildroot}%{_sbindir}

mkdir -p %{buildroot}/%{_sysconfdir}/pam.d
install -m 0644 %{_sourcedir}/vlock.pamd %{buildroot}%{_sysconfdir}/pam.d/vlock

%find_lang %{name}

%check
make check
# remove library used only for tests
rm -f $RPM_BUILD_ROOT%{_libdir}/libtswrap*
rm -f $RPM_BUILD_ROOT%{_prefix}/lib/debug/%{_libdir}/libtswrap*
perl -pi -e 'undef $_ if /libtswrap/' debugfiles.list

%files -f %{name}.lang
%{_bindir}/chvt
%{_bindir}/deallocvt
%{_bindir}/dumpkeys
%{_bindir}/fgconsole
%{_bindir}/getkeycodes
%{_bindir}/kbd_mode
%{_bindir}/kbdinfo
%{_bindir}/kbdrate
%{_bindir}/loadkeys
%{_bindir}/loadunimap
%{_bindir}/mapscrn
%{_bindir}/openvt
%{_bindir}/psfaddtable
%{_bindir}/psfgettable
%{_bindir}/psfstriptable
%{_bindir}/psfxtable
%ifarch %{ix86} x86_64
%{_bindir}/resizecons
%endif
%{_bindir}/setfont
%{_bindir}/setkeycodes
%{_bindir}/setleds
%{_bindir}/setmetamode
%{_bindir}/showconsolefont
%{_bindir}/setvtrgb
%{_bindir}/showkey
%{_bindir}/unicode_start
%{_bindir}/unicode_stop
%{_bindir}/vlock
%{_sbindir}/setsysfont
%config(noreplace) %{_sysconfdir}/pam.d/vlock
%config(noreplace) %{_sysconfdir}/profile.d/40configure_keyboard.sh
%{_mandir}/man1/chvt.1*
%{_mandir}/man1/deallocvt.1*
%{_mandir}/man1/dumpkeys.1*
%{_mandir}/man1/fgconsole.1*
%{_mandir}/man1/kbdinfo.1*
%{_mandir}/man1/kbd_mode.1*
%{_mandir}/man1/loadkeys.1*
%{_mandir}/man1/openvt.1*
%{_mandir}/man1/psfaddtable.1*
%{_mandir}/man1/psfgettable.1*
%{_mandir}/man1/psfstriptable.1*
%{_mandir}/man1/psfxtable.1*
%{_mandir}/man1/setleds.1*
%{_mandir}/man1/setmetamode.1*
%{_mandir}/man1/showkey.1*
%{_mandir}/man1/unicode_start.1*
%{_mandir}/man1/unicode_stop.1*
%{_mandir}/man1/vlock.1*
%{_mandir}/man5/keymaps.5*
%{_mandir}/man8/getkeycodes.8*
%{_mandir}/man8/kbdrate.8*
%{_mandir}/man8/loadunimap.8*
%{_mandir}/man8/mapscrn.8*
%{_mandir}/man8/resizecons.8*
%{_mandir}/man8/setfont.8*
%{_mandir}/man8/setkeycodes.8*
%{_mandir}/man8/setvtrgb.8*
%{_mandir}/man8/showconsolefont.8*
%{kbddir}


%changelog
* Mon Aug 29 2022 tv <tv> 2.5.1-1.mga9
+ Revision: 1881630
- 2.5.1
- 2.5.0
+ umeabot <umeabot>
- Mageia 9 Mass Rebuild

* Wed Dec 16 2020 tv <tv> 2.4.0-1.mga8
+ Revision: 1658046
- 2.4.0

* Wed Aug 12 2020 tv <tv> 2.3.0-1.mga8
+ Revision: 1613648
- 2.3.0

* Fri Feb 21 2020 umeabot <umeabot> 2.2.0-2.mga8
+ Revision: 1547796
- Mageia 8 Mass Rebuild

* Mon Feb 10 2020 daviddavid <daviddavid> 2.2.0-1.mga8
+ Revision: 1488419
- new version: 2.2.0
+ wally <wally>
- replace deprecated %%configure2_5x
- replace deprecated %%makeinstall_std

* Sun Sep 23 2018 umeabot <umeabot> 2.0.4-2.mga7
+ Revision: 1298440
- Mageia 7 Mass Rebuild

* Sun Jan 21 2018 wally <wally> 2.0.4-1.mga7
+ Revision: 1195519
- new version 2.0.4
- drop chvt --userwait patch as it seems to be unused

* Fri Jan 01 2016 luigiwalser <luigiwalser> 2.0.3-1.mga6
+ Revision: 917550
- 2.0.3
- rediff patch 7

* Sun Nov 01 2015 pterjan <pterjan> 2.0.2-5.mga6
+ Revision: 896988
- resizecons is only built on i586 and x86_64

* Fri Aug 21 2015 tmb <tmb> 2.0.2-4.mga6
+ Revision: 867527
- rebuild for new gcc

* Wed Oct 15 2014 umeabot <umeabot> 2.0.2-3.mga5
+ Revision: 741166
- Second Mageia 5 Mass Rebuild

* Tue Sep 16 2014 umeabot <umeabot> 2.0.2-2.mga5
+ Revision: 680938
- Mageia 5 Mass Rebuild

* Fri Jul 11 2014 luigiwalser <luigiwalser> 2.0.2-1.mga5
+ Revision: 651180
- 2.0.2
- remove upstreamed patch

* Fri Feb 21 2014 luigiwalser <luigiwalser> 2.0.1-1.mga5
+ Revision: 595332
- 2.0.1
- add patch from fedora to fix vlock PAM issues (rhbz#913311)
- remove upstreamed patch

* Thu Nov 07 2013 luigiwalser <luigiwalser> 2.0.0-3.mga4
+ Revision: 549869
- update URL
- add upstream patch for libkeymap to fix regression in processing alt_is_meta

* Sat Oct 19 2013 umeabot <umeabot> 2.0.0-2.mga4
+ Revision: 533061
- Mageia 4 Mass Rebuild

* Sat Aug 24 2013 luigiwalser <luigiwalser> 2.0.0-1.mga4
+ Revision: 471244
- 2.0.0
- remove upstreamed patch8
- rediff patch7
- BR check-devel

* Sat Aug 10 2013 luigiwalser <luigiwalser> 1.15.5-2.mga4
+ Revision: 465256
- use epoch in vlock obsoletes so that vlock package actually gets replaced
- add pam config for vlock so it will actually work (mga#10846, rhbz#913311)

* Tue Jul 23 2013 luigiwalser <luigiwalser> 1.15.5-1.mga4
+ Revision: 457483
- resizecons is built on x86_64 now
- 1.15.5
- remove upstreamed es translation patch
- add patch to fix regression in loadkeys (from upstream via fedora)
- add patch to fix decimal separator in Swiss German keyboard layout (fedora)
- fix URLs
- provide/obsolete vlock

* Thu Feb 28 2013 boklm <boklm> 1.15.3-4.mga3
+ Revision: 400675
- add bepo keymaps from http://bepo.fr/

* Sat Jan 12 2013 umeabot <umeabot> 1.15.3-3.mga3
+ Revision: 355827
- Mass Rebuild - https://wiki.mageia.org/en/Feature:Mageia3MassRebuild

* Sat Jul 21 2012 colin <colin> 1.15.3-2.mga3
+ Revision: 273158
- Update for usrmove
- Restore missing sources
+ fwang <fwang>
- new version 1.15.3
+ dmorgan <dmorgan>
- Remove mdv occurency
+ tmb <tmb>
- imported package kbd
- imported package kbd
- imported package kbd
- imported package kbd
- imported package kbd
- imported package kbd
- imported package kbd
- imported package kbd

